# To update this package you have to do it in a sequence
#
# 1. Update Version to the latest release
# 2. Go in to the SOURCES directory and run script in Source100: pack-cargo-vendor.sh
# 3. Build or send to the Build System
#
# 2019-12-08 - kekepower

# They usually say in the changelog on Github if this dep is updated. Change accordingly.
%define         min_rust_ver 1.74.0

%define		rel 1
#define		prerel rc3

Name:           alacritty
Version:        0.14.0
Release:        %mkrel %{?prerel: -c %{prerel}} %{rel}
Summary:        A cross-platform, GPU-accelerated terminal emulator
Group:          Terminals
License:        ASL 2.0
URL:            https://github.com/jwilm/alacritty
Source0:        https://github.com/jwilm/alacritty/archive/v%{version}%{?prerel:-%{prerel}}/%{name}-%{version}%{?prerel:-%{prerel}}.tar.gz

# Comment out Source1 before syncing Source0 to avoid an error message
Source1:        %{name}-cargo-vendor-%{version}%{?prerel:-%{prerel}}.tar.xz

Source4:	https://github.com/jwilm/alacritty/releases/download/v%{version}/Alacritty.svg

# This is the script that creates the Source1 tar-ball needed to build without net access.
Source100:      pack-cargo-vendor.sh

BuildRequires:  cargo >= %{min_rust_ver}
BuildRequires:  cmake
BuildRequires:  freetype-devel
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(xcb)
BuildRequires:  pkgconfig(xkbcommon)
BuildRequires:  desktop-file-utils
BuildRequires:  scdoc

Requires(post): ncurses
Requires(post): ncurses-extraterms

Recommends:     tmux

%description
Alacritty is focused on simplicity and performance. The performance goal means
it should be faster than any other terminal emulator available. The simplicity
goal means that it doesn't have features such as tabs or splits (which can be
better provided by a window manager or terminal multiplexer) nor niceties
like a GUI config editor.

The software is considered to be at an alpha level of readiness - there are
missing features and bugs to be fixed, but it is already used by many as a
daily driver.

%package zsh-completion
Summary:        A cross-platform, GPU-accelerated terminal emulator
Group:          Terminals
BuildArch:      noarch
Requires:       zsh
Requires:       %{name} >= %{version}-%{release}

%description zsh-completion
This is the shell completion for ZSH.

%package bash-completion
Summary:        A cross-platform, GPU-accelerated terminal emulator
Group:          Terminals
BuildArch:      noarch
Requires:       bash
Requires:       %{name} >= %{version}-%{release}

%description bash-completion
This is the shell completion for BASH.

%package fish-completion
Summary:        A cross-platform, GPU-accelerated terminal emulator
Group:          Terminals
BuildArch:      noarch
Requires:       fish
Requires:       %{name} >= %{version}-%{release}

%description fish-completion
This is the shell completion for FISH.

%package docs
Summary:        A cross-platform, GPU-accelerated terminal emulator
Group:          Terminals
BuildArch:      noarch
Requires:       %{name} >= %{version}-%{release}

%description docs
The documentation for %{name}.

%prep
%autosetup -a1 -p1 %{?prerel:-n %{name}-%{version}-%{prerel}}

%if 0
pushd ${HOME}
tar xf %{S:5}
tar xf %{S:6}
popd
%endif

%build
cargo build --release --verbose
cargo doc --verbose

pushd extra/man
scdoc < alacritty-bindings.5.scd > alacritty-bindings.5
scdoc < alacritty-msg.1.scd > alacritty-msg.1
scdoc < alacritty.1.scd > alacritty.1
scdoc < alacritty.5.scd > alacritty.5
popd

%install
%__mkdir_p %{buildroot}%{_bindir}
%__mkdir_p %{buildroot}%{_datadir}/applications
%__mkdir_p %{buildroot}%{_iconsdir}
%__mkdir_p %{buildroot}%{_datadir}/pixmaps
%__install -Dm 0755 extra/logo/*svg %{buildroot}%{_iconsdir}/
%__install -Dm 0755 %{S:4} %{buildroot}%{_datadir}/pixmaps/
%__install -Dm 0755 target/release/%{name} %{buildroot}%{_bindir}/%{name}
desktop-file-install extra/linux/Alacritty.desktop \
  --dir %{buildroot}%{_datadir}/applications %{buildroot}%{_datadir}/applications/Alacritty.desktop

# Shell completions
%__mkdir_p %{buildroot}%{_datadir}/zsh/site-functions/
%__mkdir_p %{buildroot}%{_datadir}/bash-completion/completions/
%__mkdir_p %{buildroot}%{_datadir}/fish/completions/
%__mkdir_p %{buildroot}%{_mandir}/man1
%__mkdir_p %{buildroot}%{_docdir}/%{name}
cp extra/completions/_%{name} %{buildroot}%{_datadir}/zsh/site-functions/_%{name}
cp extra/completions/%{name}.bash %{buildroot}%{_datadir}/bash-completion/completions/%{name}
cp extra/completions/%{name}.fish %{buildroot}%{_datadir}/fish/completions/%{name}.fish
%__install -Dm 0644 extra/%{name}.info %{buildroot}%{_docdir}/%{name}/%{name}.info
%__install -Dm 0644 extra/man/%{name}.1 %{buildroot}%{mandir}/man1/%{name}.1
%__install -Dm 0644 extra/man/%{name}-msg.1 %{buildroot}%{mandir}/man1/%{name}-msg.1
%__install -Dm 0644 extra/man/%{name}-bindings.5 %{buildroot}%{mandir}/man5/%{name}.5
%__install -Dm 0644 extra/man/%{name}.5 %{buildroot}%{mandir}/man5/%{name}.5

rm -vf %{buildroot}%{_prefix}/.crates.toml

%post
echo "        Adding %{name} info to terminfo"
tic -e alacritty,alacritty-direct %{_docdir}/%{name}/%{name}.info > /dev/null 2>&1

%files
%license LICENSE-APACHE
%doc README.md CONTRIBUTING.md
%{_bindir}/%{name}
%{_datadir}/applications/*.desktop
%{_datadir}/pixmaps/Alacritty.svg
%{_docdir}/%{name}/%{name}.info
%{_iconsdir}/%{name}*svg

%files bash-completion
%{_datadir}/bash-completion/completions/%{name}

%files fish-completion
%{_datadir}/fish/completions/%{name}.fish

%files zsh-completion
%{_datadir}/zsh/site-functions/_%{name}

%files docs
%doc target/doc/alacritty/


%changelog
* Wed Oct 23 2024 kekepower <kekepower> 0.14.0-1.mga10
+ Revision: 2110571
- Update to version 0.14.0

* Mon Mar 25 2024 kekepower <kekepower> 0.13.2-1.mga10
+ Revision: 2052065
- Update to version 0.13.2

* Thu Feb 22 2024 kekepower <kekepower> 0.13.1-1.mga10
+ Revision: 2043101
- Update to version 0.13.1

* Tue Oct 03 2023 kekepower <kekepower> 0.12.3-1.mga10
+ Revision: 1993547
- Update to version 0.12.3

* Mon Aug 28 2023 kekepower <kekepower> 0.12.2-1.mga10
+ Revision: 1980610
- Update to version 0.12.2

* Mon May 22 2023 kekepower <kekepower> 0.12.1-1.mga9
+ Revision: 1957736
- Update to version 0.12.1

* Sat Mar 25 2023 kekepower <kekepower> 0.12.0-1.mga9
+ Revision: 1950367
- Update to version 0.12.0 final

* Sat Mar 18 2023 kekepower <kekepower> 0.12.0-0.rc3.1.mga9
+ Revision: 1949635
- Update to version 0.12.0-rc3

* Thu Mar 09 2023 kekepower <kekepower> 0.12.0-0.rc2.1.mga9
+ Revision: 1948427
- Update to version 0.12.0-rc2

* Wed Feb 15 2023 kekepower <kekepower> 0.12.0-0.rc1.1.mga9
+ Revision: 1942743
- Update to version 0.12.0-rc1

* Thu Oct 13 2022 kekepower <kekepower> 0.11.0-1.mga9
+ Revision: 1896690
- Update to version 0.11.0
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Tue Feb 22 2022 kekepower <kekepower> 0.10.1-1.mga9
+ Revision: 1782802
- Update to version 0.10.1

* Sun Jan 23 2022 kekepower <kekepower> 0.10.0-1.mga9
+ Revision: 1769521
- Update to version 0.10.0

* Fri Aug 06 2021 kekepower <kekepower> 0.9.0-1.mga9
+ Revision: 1739794
- Update to version 0.9.0

* Thu May 20 2021 kekepower <kekepower> 0.8.0-1.mga9
+ Revision: 1725877
- Update to version 0.8.0

* Thu Feb 25 2021 kekepower <kekepower> 0.7.2-1.mga9
+ Revision: 1690833
- Update to version 0.7.2

* Fri Jan 15 2021 kekepower <kekepower> 0.7.1-1.mga8
+ Revision: 1671897
- Update to version 0.7.1

* Sat Aug 01 2020 kekepower <kekepower> 0.5.0-1.mga8
+ Revision: 1610377
- Update to version 0.5.0
- Bump minimum Rust version to 1.43.0

* Mon Jun 01 2020 kekepower <kekepower> 0.4.3-1.mga8
+ Revision: 1589457
- Update to version 0.4.3

* Mon Mar 30 2020 kekepower <kekepower> 0.4.2-1.mga8
+ Revision: 1562359
- Update to version 0.4.2

* Wed Feb 19 2020 umeabot <umeabot> 0.4.1-3.mga8
+ Revision: 1543170
- Mageia 8 Mass Rebuild

* Thu Jan 16 2020 kekepower <kekepower> 0.4.1-2.mga8
+ Revision: 1481155
- Alacritty no longer requires xclip (mga#26092)

* Fri Jan 10 2020 kekepower <kekepower> 0.4.1-1.mga8
+ Revision: 1477504
- Update to version 0.4.1

* Wed Nov 27 2019 kekepower <kekepower> 0.4.0-1.mga8
+ Revision: 1463080
- Update to version 0.4.0

* Sat Jun 29 2019 kekepower <kekepower> 0.3.3-1.mga8
+ Revision: 1415902
- Update to version 0.3.3

* Sat May 11 2019 kekepower <kekepower> 0.3.2-3.mga7
+ Revision: 1397283
- Rebuild for new Rust

* Sat Apr 27 2019 kekepower <kekepower> 0.3.2-2.mga7
+ Revision: 1395741
- Use default config for alacritty (alacritty.yml)

* Tue Apr 23 2019 kekepower <kekepower> 0.3.2-1.mga7
+ Revision: 1394931
- Update to version 0.3.2

* Mon Apr 22 2019 kekepower <kekepower> 0.3.1-1.mga7
+ Revision: 1394748
- Update to version 0.3.1

* Tue Apr 09 2019 kekepower <kekepower> 0.3.0-1.mga7
+ Revision: 1387233
- Update to version 0.3.0

* Wed Feb 13 2019 kekepower <kekepower> 0.2.9-1.mga7
+ Revision: 1366504
- Update to version 0.2.9

* Sun Feb 10 2019 kekepower <kekepower> 0.2.8-1.mga7
+ Revision: 1365156
- Update to version 0.2.8

* Sat Jan 26 2019 kekepower <kekepower> 0.2.7-2.mga7
+ Revision: 1361079
- Remove patch now that llvm has been fixed

* Mon Jan 21 2019 kekepower <kekepower> 0.2.7-1.mga7
+ Revision: 1359066
- Update to version 0.2.7
- Add patch to disable building with lto enabled
 o This is due to a bug or regression in either Rust or LLVM
 o See https://github.com/rust-lang/rust/issues/57762

* Tue Jan 08 2019 kekepower <kekepower> 0.2.5-1.mga7
+ Revision: 1351560
- Update to versoin 0.2.5

* Tue Dec 18 2018 kekepower <kekepower> 0.2.4-3.mga7
+ Revision: 1342489
- Requires ncurses-extraterms

* Fri Dec 14 2018 kekepower <kekepower> 0.2.4-2.mga7
+ Revision: 1341254
- Fixed font issue

* Fri Dec 14 2018 kekepower <kekepower> 0.2.4-1.mga7
+ Revision: 1341220
- imported package alacritty

